import  setuptools

setuptools.setup(
    name="xxlib",
    version="1.0.0",
    author="轩轩",
    author_email="3603695237@qq.com",
    description="轩轩库，轩轩工作室-轩轩制作，翻版、抄袭必究",
    long_desription_content_type="text/markdown",
    url="https://gitee.com/cyx200902/xxw.com",
    classmethod=[
        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
    ],
    py_modules=['xxlib\\xxsearch'],
)